@@ -67,13 +67,9 @@ pub mod client_config_api;
 pub mod devices_api;
 pub mod events_api;
 pub mod janus_api;
-pub mod ml_ops_api;
-pub mod octoprint_backups_api;
-pub mod partners_geeks3_api;
+pub mod octoprint_api;
 pub mod partners_geeks3d_api;
-pub mod remote_control_api;
 pub mod schema_api;
-pub mod telemetry_api;
 pub mod users_api;
 
 pub mod configuration;
